OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veldu skrá.",
    "File is too big" : "Skrá er of stór",
    "The selected file is not an image." : "Valda skráin er ekki mynd.",
    "The selected file cannot be read." : "Ekki hægt að lesa völdu skrána.",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "Invalid file provided" : "Ógild skrá gefin",
    "No image or file provided" : "Engin mynd eða skrá gefin",
    "Unknown filetype" : "Óþekkt skráartegund",
    "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
    "Invalid image" : "Ógild mynd",
    "No temporary profile picture available, try again" : "Engin bráðabirgða-auðkennismynd er tiltæk, reyndu aftur",
    "No crop data provided" : "Enginn gögn um utanskurð gefin",
    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
    "Crop is not square" : "Utanskurður er ekki ferningslaga",
    "State token does not match" : "Stöðuteikn samsvarar ekki",
    "Invalid app password" : "Ógilt lykilorð forrits",
    "Could not complete login" : "Gat ekki lokið innskráningu",
    "State token missing" : "Stöðuteikn vantar",
    "Your login token is invalid or has expired" : "Innskráningartákn er ógilt eða útrunnið",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru takmarkaðar.",
    "Login" : "Innskráning",
    "Unsupported email length (>255)" : "Óstudd lengd tölvupósts (>255)",
    "Password reset is disabled" : "Endurstilling lykilorðs er óvirk",
    "Could not reset password because the token is expired" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er útrunnið",
    "Could not reset password because the token is invalid" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er ógilt",
    "Password is too long. Maximum allowed length is 469 characters." : "Lykilorð er of langt, Leyfð hámarkslengd er 469 stafir.",
    "%s password reset" : "%s lykilorð endurstillt",
    "Password reset" : "Endurstilling lykilorðs",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi hnapp til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi tengil til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
    "Reset your password" : "Endurstilltu lykilorðið þitt",
    "The given provider is not available" : "Uppgefin þjónustuveita er ekki tiltæk",
    "Task not found" : "Verk fannst ekki",
    "Internal error" : "Innri villa",
    "Not found" : "Fannst ekki",
    "Bad request" : "Ógild beiðni",
    "Requested task type does not exist" : "Umbeðin tegund verks er ekki til",
    "Necessary language model provider is not available" : "Nauðsynleg tungumálslíkanaþjónusta er tiltæk",
    "No text to image provider is available" : "Engin texti-í-mynd þjónusta er tiltæk",
    "Image not found" : "Mynd fannst ekki",
    "No translation provider available" : "Engin þýðingaþjónusta tiltæk",
    "Could not detect language" : "Gat ekki greint tungumálið",
    "Unable to translate" : "Næ ekki að þýða",
    "Nextcloud Server" : "Nextcloud þjónn",
    "Some of your link shares have been removed" : "Sumir tenglar þínir á sameignir hafa verið fjarlægðir",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Vegna öryggisgalla hafa sumir tenglar þínir á sameignir hafa verið fjarlægðir. Skoðaðu tengilinn til að sjá frekari upplýsingar.",
    "The account limit of this instance is reached." : "Hámarksfjölda aðganga á þessu tilviki er náð.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Settu inn áskriftarlykilinn þinn í aðstoðarforritið til að lyfta takmörkum á aðgangnum þínum. Þetta gefur þér einnig alla viðbótareiginleikana sem Nextcloud Enterprise fyrirtækjaáskrift býður, enda er sterklega mælt með þeim fyrir verklag í fyrirtækjum.",
    "Learn more ↗" : "Kanna nánar ↗",
    "Preparing update" : "Undirbý uppfærslu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Þrep viðgerðar:",
    "Repair info:" : "Viðgerðarupplýsingar:",
    "Repair warning:" : "Viðvörun vegna viðgerðar:",
    "Repair error:" : "Villa í viðgerð:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Endilega notaðu uppfærslutólið af skipanalínu, því uppfærslur í vafra eru gerðar óvirkar í config.php.",
    "Turned on maintenance mode" : "Kveikt á viðhaldsham",
    "Turned off maintenance mode" : "Slökkt á viðhaldsham",
    "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
    "Updating database schema" : "Uppfæri gagnagrunnsskema",
    "Updated database" : "Uppfærði gagnagrunn",
    "Update app \"%s\" from App Store" : "Uppfæra forritið \"%s\" úr App Store hugbúnaðarsafni",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
    "Updated \"%1$s\" to %2$s" : "Uppfærði \"%1$s\" í %2$s",
    "Set log level to debug" : "Setja annálsstig á aflúsun",
    "Reset log level" : "Frumstilla annálsstig",
    "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
    "Finished code integrity check" : "Lauk athugun á áreiðanleika kóða",
    "%s (incompatible)" : "%s (ósamhæft)",
    "The following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
    "Already up to date" : "Allt uppfært nú þegar",
    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
    "unknown text" : "óþekktur texti",
    "Hello world!" : "Halló heimur!",
    "sunny" : "sólríkt",
    "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
    "Hello {name}" : "Halló {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hér eru leitarniðurstöðurnar þínar<script>alert(1)</script></strong>",
    "new" : "nýtt",
    "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
    "Update to {version}" : "Uppfæra í {version}",
    "An error occurred." : "Villa átti sér stað.",
    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppfærslan tókst ekki. Skoðaðu annálana á kerfisstjórnunarsíðunni og sendu inn tilkynningu um vandamálið til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud samfélagsins</a>.",
    "Continue to {productName}" : "Halda áfram í {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndu.","Uppfærslan heppnaðist. Beini þér til {productName} eftir %n sekúndur."],
    "Applications menu" : "Forritavalmynd",
    "Apps" : "Forrit",
    "More apps" : "Fleiri forrit",
    "_{count} notification_::_{count} notifications_" : ["{count} tilkynning","{count} tilkynningar"],
    "No" : "Nei",
    "Yes" : "Já",
    "The remote URL must include the user." : "Fjartengda vefslóðin þarf að innihalda notandanafnið.",
    "Invalid remote URL." : "Ógild fjartengd slóð.",
    "Failed to add the public link to your Nextcloud" : "Mistókst að bæta opinberum tengli í þitt eigið Nextcloud",
    "Federated user" : "Notandi í skýjasambandi",
    "user@your-nextcloud.org" : "notandi@þitt-nextcloud.org",
    "Create share" : "Búa til sameign",
    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald",
    "Please copy the link manually:" : "Afritaðu tengilinn handvirkt:",
    "Custom date range" : "Sérsniðið dagsetningabil",
    "Pick start date" : "Veldu upphafsdagsetningu",
    "Pick end date" : "Veldu lokadagsetningu",
    "Search in date range" : "Leita í dagsetningabili",
    "Search in current app" : "Leita í núverandi forriti",
    "Clear search" : "Hreinsa leit",
    "Search everywhere" : "Leita allsstaðar",
    "Searching …" : "Leita …",
    "Start typing to search" : "Skrifaðu hér til að leita",
    "No matching results" : "Engar samsvarandi niðurstöður",
    "Today" : "Í dag",
    "Last 7 days" : "Síðustu 7 daga",
    "Last 30 days" : "Síðustu 30 daga",
    "This year" : "Á þessu ári",
    "Last year" : "Á síðasta ári",
    "Unified search" : "Sameinuð leit",
    "Search apps, files, tags, messages" : "Leita í forritum, skrám, merkjum, skilaboðum",
    "Places" : "Staðir",
    "Date" : "Dagsetning",
    "Search people" : "Leita að fólki",
    "People" : "Fólk",
    "Filter in current view" : "Sía í núverandi sýn",
    "Results" : "Niðurstöður",
    "Load more results" : "Hlaða inn fleiri niðurstöðum",
    "Search in" : "Leita í",
    "Log in" : "Skrá inn",
    "Logging in …" : "Skrái inn …",
    "Log in to {productName}" : "Skrá inn í {productName}",
    "Wrong login or password." : "Rangur notandi eða lykilorð.",
    "This account is disabled" : "Þessi notandaaðgangur er óvirkur",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
    "Account name or email" : "Heiti aðgangs eða tölvupóstfang",
    "Account name" : "Heiti notandaaðgangs",
    "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
    "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
    "Session error" : "Villa í setu",
    "An internal error occurred." : "Innri villa kom upp.",
    "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
    "Password" : "Lykilorð",
    "Log in with a device" : "Skrá inn með tæki",
    "Login or email" : "Notandanafn eða lykilorð",
    "Your account is not setup for passwordless login." : "Aðgangur þinn er ekki uppsettur með lykilorðalausri innskráningu.",
    "Your connection is not secure" : "Tengingin þín er ekki örugg",
    "Passwordless authentication is only available over a secure connection." : "Lykilorðalaus auðkenning er aðeins tiltæk í gegnum örugga tengingu.",
    "Browser not supported" : "Það er ekki stuðningur við vafrann",
    "Passwordless authentication is not supported in your browser." : "Lykilorðalaus auðkenning er ekki studd í vafranum þínum.",
    "Reset password" : "Endursetja lykilorð",
    "Back to login" : "Til baka í innskráningu",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ef þessi aðgangur fyrirfinnst, þá hafa skilaboð um endurstillingu lykilorðs verið send á tölvupóstfang aðgangsins. Ef þú hefur ekki fengið slík skilaboð, skaltu athuga tölvupóstfangið þitt og/eða notandanafnið, skoða vel í möppur fyrir ruslpóst/rusl eða beðið kerfisstjórnendur þína um aðstoð.",
    "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
    "Password cannot be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
    "New password" : "Nýtt lykilorð",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt. Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. Viltu halda áfram?",
    "I know what I'm doing" : "Ég veit hvað ég er að gera",
    "Resetting password" : "Endurstilli lykilorð",
    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Skjöl í samstarfsvinnslu, töflureiknar og kynningar, byggt á Collabora Online.",
    "Distraction free note taking app." : "Glósuforrit án truflana.",
    "Recommended apps" : "Ráðlögð forrit",
    "Loading apps …" : "Hleð inn forritum …",
    "Could not fetch list of apps from the App Store." : "Gat ekki sótt lista yfir forrit úr App Store.",
    "App download or installation failed" : "Niðurhal eða uppsetning forrits mistókst",
    "Cannot install this app because it is not compatible" : "Ekki er hægt að setja upp forritið því það er ekki samhæft",
    "Cannot install this app" : "Get ekki sett upp þetta forrit",
    "Skip" : "Sleppa",
    "Installing apps …" : "Set upp forrit …",
    "Install recommended apps" : "Setja upp ráðlögð forrit",
    "Avatar of {displayName}" : "Auðkennismynd fyrir {displayName}",
    "Settings menu" : "Stillingavalmynd",
    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
    "Looking for {term} …" : "Leita að {term} …",
    "Search contacts" : "Leita í tengiliðum",
    "Reset search" : "Núllstilla leit",
    "Search contacts …" : "Leita í tengiliðum ",
    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
    "No contacts found" : "Engir tengiliðir fundust",
    "Show all contacts" : "Birta alla tengiliði ...",
    "Install the Contacts app" : "Setja upp tengiliðaforritið",
    "Search" : "Leita",
    "No results for {query}" : "Engar niðurstöður fyrir {query}",
    "Press Enter to start searching" : "Ýttu á Enter til að hefja leit",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Settu inn {minSearchLength} staf eða fleiri til að leita","Settu inn {minSearchLength} stafi eða fleiri til að leita"],
    "An error occurred while searching for {type}" : "Villa kom upp við leit að {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Leitin hefst um leið og byrjað er að skrifa og er hægt að flakka um leitarniðurstöður með örvalyklunum",
    "Search for {name} only" : "Leita einungis að {name}",
    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
    "Forgot password?" : "Gleymdirðu lykilorði?",
    "Back to login form" : "Til baka í innskráningarform",
    "Back" : "Til baka",
    "Login form is disabled." : "Innskráningarform er óvirkt.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Innskráningarform Nextcloud er óvirkt. Notaðu aðra aðferð til innskráningar ef slíkt er í boði eða hafðu samband við kerfisstjórnanda.",
    "More actions" : "Fleiri aðgerðir",
    "Password is too weak" : "Lykilorð er of veikt",
    "Password is weak" : "Lykilorð er veikt",
    "Password is average" : "Lykilorð er í meðallagi",
    "Password is strong" : "Lykilorð er sterkt",
    "Password is very strong" : "Lykilorð er mjög sterkt",
    "Password is extremely strong" : "Lykilorð er einstaklega sterkt",
    "Unknown password strength" : "Óþekktur styrkur lykilorðs",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að <code>.htaccess</code> skráin er ekki virk.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Til að fá upplýsingar hvernig á að stilla miðlara almennilega, skaltu skoða {linkStart}hjálparskjölin{linkEnd}",
    "Autoconfig file detected" : "Fann autoconfig-uppsetningarskrá",
    "Security warning" : "Öryggisviðvörun",
    "Create administration account" : "Búa til stjórnunaraðgang",
    "Administration account name" : "Heiti kerfisstjóraaðgangs",
    "Administration account password" : "Lykilorð kerfisstjóraaðgangs",
    "Storage & database" : "Geymsla & gagnagrunnur",
    "Data folder" : "Gagnamappa",
    "Database configuration" : "Uppsetning gagnagrunns",
    "Only {firstAndOnlyDatabase} is available." : "Aðeins {firstAndOnlyDatabase} er laust.",
    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
    "Performance warning" : "Afkastaviðvörun",
    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
    "Database user" : "Notandi gagnagrunns",
    "Database password" : "Lykilorð gagnagrunns",
    "Database name" : "Heiti gagnagrunns",
    "Database tablespace" : "Töflusvæði gagnagrunns",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
    "Database host" : "Netþjónn gagnagrunns",
    "localhost" : "localhost",
    "Installing …" : "Set upp…",
    "Install" : "Setja upp",
    "Need help?" : "Þarftu hjálp?",
    "See the documentation" : "Sjá hjálparskjölin",
    "{name} version {version} and above" : "{name} útgáfa {version} og hærri",
    "This browser is not supported" : "Það er ekki stuðningur við þennan vafra",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Það er ekki stuðningur við vafrann þinn. Endilega uppfærðu í nýrri útgáfu eða vafra sem er studdur.",
    "Continue with this unsupported browser" : "Halda áfram með þessum óstudda vafra",
    "Supported versions" : "Studdar útgáfur",
    "Search {types} …" : "Leita að {types} …",
    "Choose {file}" : "Veldu {file}",
    "Choose" : "Veldu",
    "Copy to {target}" : "Afrita í {target}",
    "Copy" : "Afrita",
    "Move to {target}" : "Færa í {target}",
    "Move" : "Færa",
    "OK" : "Í lagi",
    "read-only" : "skrifvarið",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} árekstur skráa","{count} árekstrar skráa"],
    "One file conflict" : "Einn árekstur skráa",
    "New Files" : "Nýjar skrár",
    "Already existing files" : "Skrá er nú þegar til",
    "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
    "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
    "Cancel" : "Hætta við",
    "Continue" : "Halda áfram",
    "(all selected)" : "(allt valið)",
    "({count} selected)" : "({count} valið)",
    "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
    "Saving …" : "Vista …",
    "seconds ago" : "sekúndum síðan",
    "Connection to server lost" : "Tenging við miðlara rofnaði",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
    "Add to a project" : "Bæta við verkefni",
    "Show details" : "Birta nánari upplýsingar",
    "Hide details" : "Fela nánari upplýsingar",
    "Rename project" : "Endurnefna verkefni",
    "Failed to rename the project" : "Mistókst að endurnefna verkefnið",
    "Failed to create a project" : "Mistókst að útbúa verkefni",
    "Failed to add the item to the project" : "Mistókst að bæta atriðinu í verkefnið",
    "Connect items to a project to make them easier to find" : "Að tengja atriði við verkefni gerir auðveldara að finna þau",
    "Type to search for existing projects" : "Skrifaðu hér til að leita að fyrirliggjandi verkefnum",
    "New in" : "Nýtt í",
    "View changelog" : "Skoða breytingaannál",
    "No action available" : "Engin aðgerð tiltæk",
    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
    "Close \"{dialogTitle}\" dialog" : "Loka \"{dialogTitle}\"-glugga",
    "Email length is at max (255)" : "Lengd tölvupósts er að hámarki (255)",
    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
    "Restricted" : "Takmarkað",
    "Invisible" : "Ósýnilegt",
    "Delete" : "Eyða",
    "Rename" : "Endurnefna",
    "Collaborative tags" : "Samstarfsmerkingar",
    "No tags found" : "Engin merki fundust",
    "Clipboard not available, please copy manually" : "Klippispjald er ekki tiltækt, afritaðu handvirkt",
    "Personal" : "Einka",
    "Accounts" : "Notandaaðgangar",
    "Admin" : "Stjórnun",
    "Help" : "Hjálp",
    "Access forbidden" : "Aðgangur bannaður",
    "Page not found" : "Síða fannst ekki",
    "The page could not be found on the server or you may not be allowed to view it." : "Síðan fannst ekki á netþjóninum eða að þér er ekki heimilt að skoða hana.",
    "Back to %s" : "Til baka í %s",
    "Too many requests" : "Of margar beiðnir",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
    "Error" : "Villa",
    "Internal Server Error" : "Innri villa",
    "The server was unable to complete your request." : "Þjóninum tókst ekki að afgreiða beiðnina þína.",
    "If this happens again, please send the technical details below to the server administrator." : "Ef þetta gerist aftur, sendu tæknilegu lýsinguna hér fyrir neðan til kerfisstjóra þjónsins.",
    "More details can be found in the server log." : "Nánari upplýsingar er að finna í atburðaskrá (annál) þjónsins.",
    "For more details see the documentation ↗." : "Frekari upplýsingar má sjá í hjálparskjölunum ↗.",
    "Technical details" : "Tæknilegar upplýsingar",
    "Remote Address: %s" : "fjartengt vistfang: %s",
    "Request ID: %s" : "Beiðni um auðkenni: %s",
    "Type: %s" : "Tegund: %s",
    "Code: %s" : "Kóði: %s",
    "Message: %s" : "Skilaboð: %s",
    "File: %s" : "Skrá: %s",
    "Line: %s" : "Lína: %s",
    "Trace" : "Rekja",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Það lítur út fyrir að þú sért að reyna að setja Nextcloud upp aftur. Hinsvegar vantar skrána CAN_INSTALL í grunnstillingamöppuna þína (config directory). Búðu til skrána CAN_INSTALL í grunnstillingamöppunni til að halda áfram.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Gat ekki fjarlægt CAN_INSTALL úr stillingamöppunni. Fjarlægðu þessa skrá handvirkt.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
    "Skip to main content" : "Sleppa og fara í meginefni",
    "Skip to navigation of app" : "Hlaupa yfir í flakk innan forrits",
    "Go to %s" : "Farðu í %s",
    "Get your own free account" : "Fáðu þér eigin ókeypis aðgang",
    "Connect to your account" : "Tengdu við notandaaðganginn þinn",
    "Please log in before granting %1$s access to your %2$s account." : "Skráðu þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ef þú ert ekki að reyna að setja upp nýtt tæki eða forrit, þá er einhver annar að reyna að gabba þig til að gefa þeim aðgang að gögnunum þínum. Ef svo er, skaltu ekki halda áfram í þessu ferli og hafa strax samband við kerfisstjórann þinn.",
    "App password" : "Lykilorð forrits",
    "Grant access" : "Veita aðgengi",
    "Alternative log in using app password" : "Önnur innskráning með lykilorði forrits",
    "Account access" : "Aðgangur að notandaaðgangi",
    "Currently logged in as %1$s (%2$s)." : "Í augnablikinu er skráð inn sem %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
    "Account connected" : "Aðgangur er tengdur",
    "Your client should now be connected!" : "Biðlaraforritið þitt ætti núna að vera tengt!",
    "You can close this window." : "Þú mátt loka þessum glugga.",
    "Previous" : "Fyrra",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong or expired. Please try again or request a new one." : "Lykilorðið er rangt eða útrunnið. Prófaðu aftur eða biddu um nýtt lykilorð.",
    "Please type in your email address to request a temporary password" : "Settu inn tölvupóstfangið þitt til að biðja um bráðabirgðalykilorð",
    "Email address" : "Tölvupóstfang",
    "Password sent!" : "Lykilorð sent!",
    "You are not authorized to request a password for this share" : "Þú hefur ekki heimild til að biðja um lykilorð fyrir þessa sameign",
    "Two-factor authentication" : "Tveggja-þrepa auðkenning",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnum þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Set up two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Notaðu einn af öryggisafritunarkóðunum þínum til að skrá þig inn, eða hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Use backup code" : "Nota öryggisafritskóða",
    "Cancel login" : "Hætta við innskráningu",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu hvaða auðkenningarveitu eigi að nota til auðkenningar:",
    "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
    "Access through untrusted domain" : "Tenging frá ótreystu léni",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %1$shjálparskjölunum%2$s.",
    "App update required" : "App þarfnast uppfærslu ",
    "%1$s will be updated to version %2$s" : "%1$s verður uppfært í útgáfu %2$s.",
    "The following apps will be updated:" : "Eftirfarandi forrit verða uppfærð:",
    "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
    "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gakktu úr skugga um að gagnagrunnurinn, config mappan og gagnamappan hafi verið öryggisafritaðar áður en lengra er haldið.",
    "Start update" : "Hefja uppfærslu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
    "Detailed logs" : "Ítarlegar atvikaskrár",
    "Update needed" : "Þarfnast uppfærslu",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendaaðgöngum.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
    "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
    "Maintenance mode" : "Viðhaldshamur",
    "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
    "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
    "Currently open" : "Opið núna",
    "Login with username or email" : "Skrá inn með notandanafni eða tölvupóstfangi",
    "Login with username" : "Skrá inn með notandanafni",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
    "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
    "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
    "Error opening the user status modal, try hard refreshing the page" : "Villa við að opna stöðuglugga notandans, prófaðu að þvinga endurlestur síðunnar",
    "Edit Profile" : "Breyta sniði",
    "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Miðlungs lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Profile not found" : "Sniðið finnst ekki",
    "The profile does not exist." : "Sniðið er ekki til.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Útbúa kerfisstjóraaðgang</strong>",
    "New admin account name" : "Nýtt heiti kerfisstjóraaðgangs",
    "New admin password" : "Nýtt lykilorð kerfisstjóra",
    "Show password" : "Sýna lykilorð",
    "Toggle password visibility" : "Breyta sýnileika lykilorðs",
    "Configure the database" : "Stilla gagnagrunninn",
    "Only %s is available." : "Aðeins %s eru laus.",
    "Database account" : "Gagnagrunnsaðgangur"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
